/*
 * VSGraphXApi.h
 *
 * Copyright (C) 2002-2005 Vectorsoft - www.vectorsoft.gr
 *
 * This file defines the Application Programming Interface for
 * using the VSGraphX DLL.
 */


/*
 *
 *					VSGraphX DLL API Specification
 *
 *
 *	VSGraphX DLL API allows you to use the VSGraphX DLL to:
 *
 *		Open and save vector drawing files.
 *		Display vector drawings.
 *		Get information for vector drawings and their graphics entities.
 *		Create new vector drawings.
 *		Add graphics entities to vector drawings.
 *
 *
 *	Supported file formats:
 *
 *		Open:
 *			Adobe AI (up to version 10).
 *			AutoCAD DXF (up to version 2002).
 *			Windows EMF.
 *			Windows WMF.
 *			HPGL Plotter (PLT).
 *		Save:
 *			Adobe AI (version 7).
 *			AutoCAD DXF (version 2002).
 *			Windows EMF.
 *			HPGL Plotter (PLT).
 *
 *	All Trademarks belong to their respective owners.
 *
 *
 *	Supported graphics entities:
 *
 *		PolyBezier path.
 *		Text.
 *		Bitmap.
 *
 *
 *	API supported languages:
 *
 *		C, C++.
 *
 *
 *
 *
 *
 *
 *					VSGraphX C API Specification
 *
 *
 *	Functions:
 *
 *		Open vector drawing files:
 *			VSGRAPHXOpen().
 *			VSGRAPHXOpenAI().
 *			VSGRAPHXOpenDXF().
 *			VSGRAPHXOpenEMF().
 *			VSGRAPHXOpenWMF().
 *			VSGRAPHXOpenPLT().
 *
 *		Save vector drawing files:
 *			VSGRAPHXSave().
 *			VSGRAPHXSaveAI().
 *			VSGRAPHXSaveDXF().
 *			VSGRAPHXSaveEMF().
 *			VSGRAPHXSavePLT().
 *
 *		Display vector drawings:
 *			VSGRAPHXDraw().
 *			VSGRAPHXDrawArea().
 *
 *		Create vector drawings:
 *			VSGRAPHXCreate().
 *
 *		Close vector drawings:
 *			VSGRAPHXClose().
 *
 *		Get information for vector drawings and their graphics entities:
 *			VSGRAPHXGetBounds().
 *			VSGRAPHXGetLeft().
 *			VSGRAPHXGetTop().
 *			VSGRAPHXGetRight().
 *			VSGRAPHXGetBottom().
 *			VSGRAPHXGetWidth().
 *			VSGRAPHXGetHeight().
 *			VSGRAPHXGetEntityBounds().
 *			VSGRAPHXGetEntityLeft().
 *			VSGRAPHXGetEntityTop().
 *			VSGRAPHXGetEntityRight().
 *			VSGRAPHXGetEntityBottom().
 *			VSGRAPHXGetEntityWidth().
 *			VSGRAPHXGetEntityHeight().
 *			VSGRAPHXGetNumOfEntities().
 *			VSGRAPHXGetEntityType().
 *			VSGRAPHXGetPolyBezierPathInfo().
 *			VSGRAPHXGetPolyBezierPathSize().
 *			VSGRAPHXGetBezierPathSize().
 *			VSGRAPHXGetBezierPathTriplet().
 *			VSGRAPHXGetTextInfo().
 *			VSGRAPHXGetFontName().
 *			VSGRAPHXGetText().
 *			VSGRAPHXGetBitmap().
 *
 *		Add graphics entities to vector drawings:
 *			VSGRAPHXBeginPolyBezierPath().
 *			VSGRAPHXAddBezierPathTriplet().
 *			VSGRAPHXAddBezierPath().
 *			VSGRAPHXAddPolyBezierPath().
 *			VSGRAPHXAddText().
 *			VSGRAPHXAddBitmap().
 *
 *		Units handling:
 *			VSGRAPHXGetUnits().
 *			VSGRAPHXSetUnits().
 *
 *		Other functions:
 *			VSGRAPHXCreateIcon().
 *			VSGRAPHXCreateBitmap24().
 */

#if !defined(_VSGRAPHXAPI_INCLUDED)
#define _VSGRAPHXAPI_INCLUDED


#ifdef  __cplusplus 
extern "C"
{
#endif

/*
 * error return code
 */
#define VSGRAPHX_ERROR	-1


/* input:	filepath	-	The filepath of the drawing file to be opened.
 *			
 * returns:	The vsgraphx handle to the drawing opened, or VSGRAPHX_ERROR in case 
 *			of failure.
 *
 * remarks:	Opens a drawing file. The drawing file type is obtained from the file 
 *			extension.
 */
int VSGRAPHXOpen(LPCTSTR filepath);


/* input:	filepath	-	The filepath of the drawing file to be opened.
 *			
 * returns:	The vsgraphx handle to the drawing opened, or VSGRAPHX_ERROR in case 
 *			of failure.
 *
 * remarks:	Opens an AI drawing file, regardless of the file extension.
 */
int VSGRAPHXOpenAI(LPCTSTR filepath);


/* input:	filepath	-	The filepath of the drawing file to be opened.
 *			
 * returns:	The vsgraphx handle to the drawing opened, or VSGRAPHX_ERROR in case 
 *			of failure.
 *
 * remarks:	Opens a DXF drawing file, regardless of the file extension.
 */
int VSGRAPHXOpenDXF(LPCTSTR filepath);


/* input:	filepath	-	The filepath of the drawing file to be opened.
 *			
 * returns:	The vsgraphx handle to the drawing opened, or VSGRAPHX_ERROR in case 
 *			of failure.
 *
 * remarks:	Opens an EMF drawing file, regardless of the file extension.
 */
int VSGRAPHXOpenEMF(LPCTSTR filepath);


/* input:	filepath	-	The filepath of the drawing file to be opened.
 *			
 * returns:	The vsgraphx handle to the drawing opened, or VSGRAPHX_ERROR in case 
 *			of failure.
 *
 * remarks:	Opens a WMF drawing file, regardless of the file extension.
 */
int VSGRAPHXOpenWMF(LPCTSTR filepath);


/* input:	filepath	-	The filepath of the drawing file to be opened.
 *			
 * returns:	The vsgraphx handle to the drawing opened, or VSGRAPHX_ERROR in case 
 *			of failure.
 *
 * remarks:	Opens a PLT drawing file, regardless of the file extension.
 */
int VSGRAPHXOpenPLT(LPCTSTR filepath);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing to be saved.
 *
 *			filepath	-	The filepath of the drawing file to be saved.
 *			
 * returns:	TRUE for success, FALSE for failure.
 *
 * remarks:	Saves a drawing file. The drawing file type is obtained by the file 
 *			extension.
 */
BOOL VSGRAPHXSave(int vsgraphx, LPCTSTR filepath);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing to be saved.
 *
 *			filepath	-	The filepath of the drawing file to be saved.
 *			
 * returns:	TRUE for success, FALSE for failure.
 *
 * remarks:	Saves an AI drawing file, regardless of the file extension.
 */
BOOL VSGRAPHXSaveAI(int vsgraphx, LPCTSTR filepath);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing to be saved.
 *
 *			filepath	-	The filepath of the drawing file to be saved.
 *			
 * returns:	TRUE for success, FALSE for failure.
 *
 * remarks:	Saves a DXF drawing file, regardless of the file extension.
 */
BOOL VSGRAPHXSaveDXF(int vsgraphx, LPCTSTR filepath);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing to be saved.
 *
 *			filepath	-	The filepath of the drawing file to be saved.
 *			
 * returns:	TRUE for success, FALSE for failure.
 *
 * remarks:	Saves an EMF drawing file, regardless of the file extension.
 */
BOOL VSGRAPHXSaveEMF(int vsgraphx, LPCTSTR filepath);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing to be saved.
 *
 *			filepath	-	The filepath of the drawing file to be saved.
 *			
 * returns:	TRUE for success, FALSE for failure.
 *
 * remarks:	Saves a PLT drawing file, regardless of the file extension.
 */
BOOL VSGRAPHXSavePLT(int vsgraphx, LPCTSTR filepath);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			hDC			-	The HDC that will be used.
 *
 *			drawRect	-	The rectangle (in hDC logical units) where the drawing 
 *							will fit.
 *
 * remarks:	Draws a drawing to the argument HDC and fits it into the rectangle
 *			specified by the drawRect argument.
 */
void VSGRAPHXDraw(int vsgraphx, HDC hDC, LPCRECT drawRect);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			hDC			-	The HDC that will be used.
 *
 *			drawRect	-	The rectangle (in hDC logical units) where the drawing's
 *							area will fit.
 *
 *			areaLeft	-	The left position (in drawing's units) of the drawing's area.
 *
 *			areaTop		-	The top position (in drawing's units) of the drawing's area.
 *
 *			areaRight	-	The right position (in drawing's units) of the drawing's area.
 *
 *			areaBottom	-	The bottom position (in drawing's units) of the drawing's area.
 *
 * remarks:	Draws a rectangle area of a drawing to the argument HDC, and fits this area
 *			into the rectangle specified by the drawRect argument.
 */
void VSGRAPHXDrawArea(int vsgraphx, HDC hDC, LPCRECT drawRect, 
		double areaLeft, double areaTop, double areaRight, double areaBottom);


/* returns:	The vsgraphx handle to the new drawing. In case of failure returns
 *			VSGRAPHX_ERROR.
 *
 * remarks:	Creates a new drawing.
 */
int VSGRAPHXCreate();


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * remarks:	Closes the vsgraphx handle to a drawing and releases all associated
 *			resources. Should be called for every vsgraphx handle opened or created.
 */
void VSGRAPHXClose(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * output:	left		-	The left position of the drawing (in drawing's units).
 *
 *			top			-	The top position of the drawing (in drawing's units).
 *
 *			right		-	The right position of the drawing (in drawing's units).
 *
 *			bottom		-	The bottom position of the drawing (in drawing's units).
 *
 * returns: TRUE for success, FALSE for failure.
 *
 * remarks:	Gets the boundaries of a drawing (in drawing's units).
 */
BOOL VSGRAPHXGetBounds(int vsgraphx, double *left, double *top, double *right, double *bottom);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	The left position of the drawing (in drawing's units).
 */
double VSGRAPHXGetLeft(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	The top position of the drawing (in drawing's units).
 */
double VSGRAPHXGetTop(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	The right position of the drawing (in drawing's units).
 */
double VSGRAPHXGetRight(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	The bottom position of the drawing (in drawing's units).
 */
double VSGRAPHXGetBottom(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	The width of the drawing (in drawing's units).
 */
double VSGRAPHXGetWidth(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	The height of the drawing (in drawing's units).
 */
double VSGRAPHXGetHeight(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * output:	left		-	The left position of the graphics entity (in drawing's
 *							units).
 *
 *			top			-	The top position of the graphics entity (in drawing's
 *							units).
 *
 *			right		-	The right position of the graphics entity (in drawing's
 *							units).
 *
 *			bottom		-	The bottom position of the graphics entity (in drawing's
 *							units).
 *
 * returns: TRUE for success, FALSE for failure.
 *
 * remarks:	Gets the boundaries of a graphics entity (in drawing's units).
 */
BOOL VSGRAPHXGetEntityBounds(int vsgraphx, int index, 
							 double *left, double *top, double *right, double *bottom);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * returns:	The left position of the graphics entity (in drawing's units).
 */
double VSGRAPHXGetEntityLeft(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * returns:	The top position of the graphics entity (in drawing's units).
 */
double VSGRAPHXGetEntityTop(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * returns:	The right position of the graphics entity (in drawing's units).
 */
double VSGRAPHXGetEntityRight(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * returns:	The bottom position of the graphics entity (in drawing's units).
 */
double VSGRAPHXGetEntityBottom(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * returns:	The width of the graphics entity (in drawing's units).
 */
double VSGRAPHXGetEntityWidth(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * returns:	The height of the graphics entity (in drawing's units).
 */
double VSGRAPHXGetEntityHeight(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing
 *			
 * returns:	The number of graphics entities in the drawing.
 */
int VSGRAPHXGetNumOfEntities(int vsgraphx);


//Entity types definitions
#define VSGRAPHX_ENTITY_POLYBEZIER	1
#define VSGRAPHX_ENTITY_TEXT		2
#define VSGRAPHX_ENTITY_BITMAP		3

/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the graphics entity in the drawing.
 *			
 * returns:	The graphics entity's type. It can be one of the following: 
 *			VSGRAPHX_ENTITY_POLYBEZIER, VSGRAPHX_ENTITY_TEXT, VSGRAPHX_ENTITY_BITMAP.
 *			In case of failure returns VSGRAPHX_ERROR.
 */
int VSGRAPHXGetEntityType(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the PolyBezierPath entity in the drawing.
 *
 * output:	pnWidth		-	The pen width (in drawing's units) of the PolyBezierPath
 *							entity.
 *
 *			pnStyle		-	The pen style of the PolyBezierPath entity.
 *
 *			pnColor		-	The pen color of the PolyBezierPath entity.
 *
 *			brStyle		-	The brush style of the PolyBezierPath entity.
 *
 *			brColor		-	The brush color of the PolyBezierPath entity.
 *
 *			hatch		-	The hatch style of the PolyBezierPath entity.
 *
 * returns: TRUE for success, FALSE for failure.
 *			
 * remarks:	Gets the info about the pen and brush that are used for drawing a
 *			PolyBezierPath entity.
 */
BOOL VSGRAPHXGetPolyBezierPathInfo(int vsgraphx, int index, double *pnWidth,
								   UINT *pnStyle, COLORREF *pnColor, UINT *brStyle, 
								   COLORREF *brColor, LONG *hatch);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the PolyBezierPath entity in the drawing.
 *			
 * returns:	The number of Bezier paths that a PolyBezier path has.
 */
int VSGRAPHXGetPolyBezierPathSize(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the PolyBezierPath entity in the drawing.
 *
 *			path		-	The index of the Bezier path in the PolyBezierPath entity.
 *			
 * returns:	The number of triplets that a Bezier path has.
 */
int VSGRAPHXGetBezierPathSize(int vsgraphx, int index, int path);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the PolyBezierPath entity in the drawing.
 *
 *			path		-	The index of the Bezier path in the PolyBezierPath entity.
 *
 *			trIndex		-	The index of the triplet in the Bezier path.
 *
 * output:	preDirPoX	-	The x coordinate (in drawing's units) of the triplet's
 *							pre-direction point.
 *
 *			preDirPoY	-	The y coordinate (in drawing's units) of the triplet's
 *							pre-direction point.
 *
 *			anchPoX		-	The x coordinate (in drawing's units) of the triplet's
 *							anchor point.
 *
 *			anchPoY		-	The y coordinate (in drawing's units) of the triplet's
 *							anchor point.
 *
 *			postDirPoX	-	The x coordinate (in drawing's units) of the triplet's
 *							post-direction point.
 *
 *			postDirPoY	-	The y coordinate (in drawing's units) of the triplet's
 *							post-direction point.
 *
 * returns: TRUE for success, FALSE for failure.
 *			
 * remarks:	Gets the coordinates (in drawing's units) of a Bezier path triplet.
 */
BOOL VSGRAPHXGetBezierPathTriplet(int vsgraphx, int index, int path, int trIndex,
								  double *preDirPoX, double *preDirPoY, 
								  double *anchPoX,  double *anchPoY, 
								  double *postDirPoX, double *postDirPoY);


//Text styles definitions
#define VSGRAPHX_TEXT_STYLE_NORMAL		0
#define VSGRAPHX_TEXT_STYLE_ITALIC		1
#define VSGRAPHX_TEXT_STYLE_BOLD		2
#define VSGRAPHX_TEXT_STYLE_UNDERLINE	4

/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the Text entity in the drawing.
 *
 * output:	poX			-	The x coordinate (in drawing's units) of the Text entity's
 *							top left point.
 *
 *			poY			-	The y coordinate (in drawing's units) of the Text entity's 
 *							top left point.
 *
 *			style		-	The style of the Text entity. The text style can be a
 *							combination of the following: VSGRAPHX_TEXT_STYLE_NORMAL,
 *							VSGRAPHX_TEXT_STYLE_ITALIC, VSGRAPHX_TEXT_STYLE_BOLD,
 *							VSGRAPHX_TEXT_STYLE_UNDERLINE.
 *
 *			height		-	The height (in drawing's units) of the Text entity.
 *
 *			angle		-	The angle (in degrees) of the Text entity.
 *
 *			color		-	The color of the Text entity.
 *
 * returns: TRUE for success, FALSE for failure.
 *			
 * remarks:	Gets the coordinates (in drawing's units) of a Text entity's top left point,
 *			as well as the style, height (in drawing's units), angle (in degrees) and
 *			color of the Text entity.
 */
BOOL VSGRAPHXGetTextInfo(int vsgraphx, int index, double *poX, double *poY, BYTE *style, 
						 double *height, double *angle, COLORREF *color);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the Text entity in the drawing.
 *
 *			nSize		-	Specifies the length, of the lpFontName buffer. If the
 *							length of the font name exceeds this limit, the string
 *							is truncated.
 *
 * output:	lpFontName	-	A buffer that receives the font name string.
 *
 * returns:	The length of the string copied to the buffer. If the lpFontName argument
 *			is NULL, it returns the actual length of the font name string. In case
 *			of failure returns VSGRAPHX_ERROR.
 */
int VSGRAPHXGetFontName(int vsgraphx, int index, LPTSTR lpFontName, DWORD nSize);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the Text entity in the drawing.
 *
 *			nSize		-	Specifies the length, of the lpText buffer. If the length
 *							of the text exceeds this limit, the string is truncated.
 *
 * output:	lpText		-	A buffer that receives the text string.
 *
 * returns:	The length of the string copied to the buffer. If the lpText argument
 *			is NULL, it returns the actual length of the Text entity's string. In
 *			case of failure returns VSGRAPHX_ERROR.
 */
int VSGRAPHXGetText(int vsgraphx, int index, LPTSTR lpText, DWORD nSize);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			index		-	The index of the Bitmap entity in the drawing.
 *			
 * returns:	The HBITMAP of the Bitmap entity, or NULL in case of failure.
 *
 * remarks: Do not destroy the returned HBITMAP. It will be destroyed by VSGRAPHXClose().
 */
HBITMAP VSGRAPHXGetBitmap(int vsgraphx, int index);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			pnWidth		-	The pen width (in drawing's units) of the PolyBezierPath
 *							entity.
 *
 *			pnStyle		-	The pen style of the PolyBezierPath entity.
 *
 *			pnColor		-	The pen color of the PolyBezierPath entity.
 *
 *			brStyle		-	The brush style of the PolyBezierPath entity.
 *
 *			brColor		-	The brush color of the PolyBezierPath entity.
 *
 *			hatch		-	The hatch style of the PolyBezierPath entity.
 *			
 * returns:	TRUE if vsgraphx is valid. FALSE otherwise.
 *
 * remarks:	Begins the creation of a PolyBezierPath entity and sets the info about the 
 *			pen and brush that are used for drawing this entity. The entity must be 
 *			filled with Bezier path triplets using the VSGRAPHXAddBezierPathTriplet()
 *			function. Multiple Bezier paths can be added to the PolyBezierPath entity 
 *			using the VSGRAPHXAddBezierPath() function.
 */
BOOL VSGRAPHXBeginPolyBezierPath(int vsgraphx, double pnWidth, UINT pnStyle, 
								 COLORREF pnColor, UINT brStyle, COLORREF brColor,
								 LONG hatch);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			preDirPoX	-	The x coordinate (in drawing's units) of the triplet's
 *							pre-direction point.
 *
 *			preDirPoY	-	The y coordinate (in drawing's units) of the triplet's
 *							pre-direction point.
 *
 *			anchPoX		-	The x coordinate (in drawing's units) of the triplet's
 *							anchor point.
 *
 *			anchPoY		-	The y coordinate (in drawing's units) of the triplet's
 *							anchor point.
 *
 *			postDirPoX	-	The x coordinate (in drawing's units) of the triplet's
 *							post-direction point.
 *
 *			postDirPoY	-	The y coordinate (in drawing's units) of the triplet's
 *							post-direction point.
 *			
 * returns:	TRUE if vsgraphx is valid and VSGRAPHXBeginPolyBezierPath() has been
 *			called. FALSE otherwise.
 *
 * remarks:	Adds a Bezier path triplet to the current Bezier path of the PolyBezierPath
 *			entity under creation.
 */
BOOL VSGRAPHXAddBezierPathTriplet(int vsgraphx,
								  double preDirPoX, double preDirPoY, 
								  double anchPoX,  double anchPoY, 
								  double postDirPoX, double postDirPoY);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	TRUE if vsgraphx is valid and VSGRAPHXBeginPolyBezierPath() has been
 *			called and the current Bezier path of the PolyBezierPath entity is not
 *			empty. FALSE otherwise.
 *
 * remarks:	Adds another Bezier path to the PolyBezierPath entity under creation.
 *			It is needed only for PolyBezierPath entities that contain more than
 *			one Bezier paths.
 */
BOOL VSGRAPHXAddBezierPath(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	TRUE if vsgraphx is valid and a PolyBezierPath entity has been created
 *			using the VSGRAPHXBeginPolyBezierPath() and VSGRAPHXAddBezierPathTriplet()
 *			functions. FALSE otherwise.
 *
 * remarks:	Adds a PolyBezier path to the end of a drawing. The PolyBezier path
 *			must have been created using the VSGRAPHXBeginPolyBezierPath() and
 *			VSGRAPHXAddBezierPathTriplet() functions. For PolyBezierPath entities that
 *			have more than one Bezier paths, VSGRAPHXAddBezierPath() must also have 
 *			been used.
 */
BOOL VSGRAPHXAddPolyBezierPath(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			text		-	The text string of the Text entity.
 *
 *			fontName	-	The font name string of the Text entity.
 *
 *			poX			-	The x coordinate (in drawing's units) of the Text entity's
 *							top left point.
 *
 *			poY			-	The y coordinate (in drawing's units) of the Text entity's
 *							top left point.
 *
 *			style		-	The style of the Text entity. The text style can be a
 *							combination of the following: VSGRAPHX_TEXT_STYLE_NORMAL,
 *							VSGRAPHX_TEXT_STYLE_ITALIC, VSGRAPHX_TEXT_STYLE_BOLD, 
 *							VSGRAPHX_TEXT_STYLE_UNDERLINE.
 *
 *			height		-	The height (in drawing's units) of the Text entity.
 *
 *			angle		-	The angle (in degrees) of the Text entity.
 *
 *			color		-	The color of the Text entity.
 *			
 * returns:	TRUE for success, FALSE for failure.
 *
 * remarks:	Adds a Text entity to the end of a drawing.
 */
BOOL VSGRAPHXAddText(int vsgraphx, LPCTSTR text, LPCTSTR fontName, double poX, double poY,
					 BYTE style, double height, double angle, COLORREF color);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			hBmp		-	The HBITMAP of the Bitmap entity. This HBITMAP will be
 *							deleted by VSGRAPHXClose().
 *
 *			left		-	The left position (in drawing's units) of the Bitmap entity.
 *
 *			top			-	The top position (in drawing's units) of the Bitmap entity.
 *
 *			right		-	The right position (in drawing's units) of the Bitmap entity.
 *
 *			bottom		-	The bottom position (in drawing's units) of the Bitmap entity.
 *			
 * returns:	TRUE for success, FALSE for failure.
 *
 * remarks:	Adds a Bitmap entity to the end of a drawing.
 */
BOOL VSGRAPHXAddBitmap(int vsgraphx, HBITMAP hBmp, 
					   double left, double top, double right, double bottom);


//Units definitions
#define VSGRAPHX_UNITS_PX	1	//pixels
#define VSGRAPHX_UNITS_MM10	2	//tenths of millimetres
#define VSGRAPHX_UNITS_MM	3	//millimetres
#define VSGRAPHX_UNITS_CM	4	//centimetres
#define VSGRAPHX_UNITS_IN	5	//inches

/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *			
 * returns:	The units that are used in the drawing. Possible values are VSGRAPHX_UNITS_PX,
 *			VSGRAPHX_UNITS_MM10, VSGRAPHX_UNITS_MM, VSGRAPHX_UNITS_CM, VSGRAPHX_UNITS_IN 
 *			and VSGRAPHX_ERROR in case of failure. The default units in a drawing are 
 *			tenths of millimeters (VSGRAPHX_UNITS_MM10).
 */
int VSGRAPHXGetUnits(int vsgraphx);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			units		-	The units to be used in the drawing. Possible values are
 *							VSGRAPHX_UNITS_PX, VSGRAPHX_UNITS_MM10, VSGRAPHX_UNITS_MM, 
 *							VSGRAPHX_UNITS_CM, VSGRAPHX_UNITS_IN.
 *			
 * remarks:	Sets the units to be used in a drawing. The default units in a drawing are
 *			tenths of millimeters (VSGRAPHX_UNITS_MM10).
 */
void VSGRAPHXSetUnits(int vsgraphx, int units);


/* input:	vsgraphx	-	The vsgraphx handle to the drawing.
 *
 *			width		-	The width of the icon.
 *
 *			height		-	The height of the icon.
 *
 *			first		-	The index of the first graphics entity to be drawn to 
 *							the icon.
 *
 *			last		-	The index of the last graphics entity to be drawn to 
 *							the icon.
 *
 * returns: The HBITMAP of the icon, or NULL in case of failure.
 *			
 * remarks: Creates an icon containing some graphics entities of a drawing. The returned
 *			HBITMAP must be deleted when it is no longer needed.
 */
HBITMAP VSGRAPHXCreateIcon(int vsgraphx, int width, int height, int first, int last);


/* input:	hBmp		-	The HBITMAP to be copied.
 *			
 * returns:	A new 24-bit device independent HBITMAP with the image of the argument HBITMAP.
 *			The returned HBITMAP must be deleted when it is no longer needed.
 */
HBITMAP VSGRAPHXCreateBitmap24(HBITMAP hBmp);










#ifdef  __cplusplus 
}	/* extern "C" */
#endif



#ifdef __cplusplus


/*
 *
 *					CVSGraphX Class Specification
 *
 *
 *		The CVSGraphX class is a wrapper class for the C VSGraphX DLL API. It offers
 *	to C++ programmers a more efficient way to use VSGraphX DLL.
 *
 *
 *	Methods:
 *
 *		Open vector drawing files:
 *			Open().
 *
 *		Save vector drawing files:
 *			Save().
 *
 *		Display vector drawings:
 *			Draw().
 *			DrawArea().
 *
 *		Create vector drawings:
 *			Create().
 *
 *		Close vector drawings:
 *			Close().
 *
 *		Get information for vector drawings and their graphics entities:
 *			GetBounds().
 *			GetLeft().
 *			GetTop().
 *			GetRight().
 *			GetBottom().
 *			GetWidth().
 *			GetHeight().
 *			GetEntityBounds().
 *			GetEntityLeft().
 *			GetEntityTop().
 *			GetEntityRight().
 *			GetEntityBottom().
 *			GetEntityWidth().
 *			GetEntityHeight().
 *			GetNumOfEntities().
 *			GetEntityType().
 *			GetPolyBezierPathInfo().
 *			GetPolyBezierPathSize().
 *			GetBezierPathSize().
 *			GetBezierPathTriplet().
 *			GetTextInfo().
 *			GetFontName().
 *			GetText().
 *			GetBitmap().
 *
 *		Add graphics entities to vector drawings:
 *			BeginPolyBezierPath().
 *			AddBezierPathTriplet().
 *			AddBezierPath().
 *			AddPolyBezierPath().
 *			AddText().
 *			AddBitmap().
 *
 *		Units handling:
 *			GetUnits().
 *			SetUnits().
 *
 *		Other functions:
 *			CreateIcon().
 *			CreateBitmap24().
 */
 
class CVSGraphX  
{
public:
	/* Constructor */
	CVSGraphX()
	{
		m_vsgraphx = -1;	//not initialized yet
	}

	/* Destructor */
	virtual ~CVSGraphX()
	{
		Close();	//clears information about the last opened vsgraphx handle
	}

	/* Supported file types (any stands for all valid types) */
	enum FileType
	{
		ANY,
		AI,
		DXF,
		EMF,
		WMF,
		PLT
	};

	/* input:	filepath	-	The filepath of the drawing file to be opened.
	 *
	 *			type		-	The type of the drawing file (ANY, AI, DXF, EMF, WMF, 
	 *							PLT). If it is ANY, the type is obtained from the
	 *							file extension, otherwise the file extension is ignored.
	 *
	 * returns:	TRUE if the drawing file is sucsessfully opened, FALSE otherwise.
	 *
	 * remarks:	Opens a drawing file.
	 */
	BOOL Open(LPCTSTR filepath, FileType type = ANY)
	{
		Close();
		
		switch(type)
		{
			case AI:	
				m_vsgraphx = VSGRAPHXOpenAI(filepath);
				break;
			case DXF:
				m_vsgraphx = VSGRAPHXOpenDXF(filepath);
				break;
			case EMF:
				m_vsgraphx = VSGRAPHXOpenEMF(filepath);
				break;
			case WMF:
				m_vsgraphx = VSGRAPHXOpenWMF(filepath);
				break;
			case PLT:
				m_vsgraphx = VSGRAPHXOpenPLT(filepath);
				break;
			case ANY:
			default:
				m_vsgraphx = VSGRAPHXOpen(filepath);
				break;
		}

		return m_vsgraphx >= 0;
	}


	/* input:	filepath	-	The filepath of the drawing file to be saved.
	 *
	 *			type		-	The type of the drawing file (ANY, AI, DXF, EMF, WMF, 
	 *							PLT). If it is ANY, the type is obtained from the
	 *							file extension, otherwise the file extension is ignored.
	 *
	 * returns:	TRUE if the drawing file is successfully saved, FALSE otherwise.
	 *
	 * remarks:	Saves a drawing file.
	 */
	BOOL Save(LPCTSTR filepath, FileType type = ANY)
	{
		switch(type)
		{
			case AI:	
				return VSGRAPHXSaveAI(m_vsgraphx, filepath);
				break;
			case DXF:
				return VSGRAPHXSaveDXF(m_vsgraphx, filepath);
				break;
			case EMF:
				return VSGRAPHXSaveEMF(m_vsgraphx, filepath);
				break;
			case PLT:
				return VSGRAPHXSavePLT(m_vsgraphx, filepath);
				break;
			case ANY:
			default:
				return VSGRAPHXSave(m_vsgraphx, filepath);
				break;
		}
	}

	
	/* input:	hDC			-	The HDC that will be used.
	 *
	 *			drawRect	-	The rectangle (in hDC logical units) where the drawing
	 *							will fit.
	 *
	 * remarks:	Draws a drawing to the argument HDC, and fits it into the rectangle
	 *			specified by the drawRect argument.
	 */
	void Draw(HDC hDC, LPCRECT drawRect)
	{
		VSGRAPHXDraw(m_vsgraphx, hDC, drawRect);
	}

	
	/* input:	hDC			-	The HDC that will be used.
	 *
	 *			drawRect	-	The rectangle (in hDC logical units) where the drawing's
	 *							area will fit.
	 *
	 *			areaRect	-	The rectangle (in drawing's units) of the drawing's
	 *							area.
	 *
	 * remarks:	Draws a rectangle area of a drawing to the argument HDC, and fits this
	 *			area into the rectangle specified by the drawRect argument.
	 */
	void DrawArea(HDC hDC, LPCRECT drawRect, LPCRECT areaRect)
	{
		CRect rect = (CRect) areaRect;
		VSGRAPHXDrawArea(m_vsgraphx, hDC, drawRect, 
						 (double) rect.left, 
						 (double) rect.top, 
						 (double) rect.right, 
						 (double) rect.bottom
						);
	}

	
	/* input:	hDC			-	The HDC that will be used.
	 *
	 *			drawRect	-	The rectangle (in hDC logical units) where the drawing's
	 *							area will fit.
	 *
	 *			areaLeft	-	The left position (in drawing's units) of the drawing's
	 *							area.
	 *
	 *			areaTop		-	The top position (in drawing's units) of the drawing's
	 *							area.
	 *
	 *			areaRight	-	The right position (in drawing's units) of the drawing's
	 *							area.
	 *
	 *			areaBottom	-	The bottom position (in drawing's units) of the drawing's
	 *							area.
	 *
	 * remarks:	Draws a rectangle area of a drawing to the argument HDC, and fits this
	 *			area into the rectangle specified by the drawRect argument.
	 */
	void DrawArea(HDC hDC, LPCRECT drawRect, double areaLeft, double areaTop,
				  double areaRight, double areaBottom)
	{
		VSGRAPHXDrawArea(m_vsgraphx, hDC, drawRect, 
						 (double) areaLeft, 
						 (double) areaTop, 
						 (double) areaRight, 
						 (double) areaBottom
						);
	}


	/* returns:	TRUE if the new drawing is sucsessfully created.
	 *
	 * remarks:	Creates a new drawing.
	 */
	BOOL Create()
	{
		Close();
		m_vsgraphx = VSGRAPHXCreate();

		return m_vsgraphx >= 0;
	}


	/* remarks:	Closes the vsgraphx handle to a drawing and releases all associated
	 *			resources. It is automatically called in an object's destruction.
	 */
	void Close()
	{
		VSGRAPHXClose(m_vsgraphx);
		m_vsgraphx = -1;
	}


	/* output:	left	-	The left position of the drawing (in drawing's units).
	 *
	 *			top		-	The top position of the drawing (in drawing's units).
	 *
	 *			right	-	The right position of the drawing (in drawing's units).
	 *
	 *			bottom	-	The bottom position of the drawing (in drawing's units).
	 *
	 * returns: TRUE for success, FALSE for failure.
	 *
	 * remarks:	Gets the boundaries of a drawing (in drawing's units).
	 */
	BOOL GetBounds(double *left, double *top, double *right, double *bottom)
	{
		return VSGRAPHXGetBounds(m_vsgraphx, left, top, right, bottom);
	}
	
	/* returns:	The left position of the drawing (in drawing's units). */
	double GetLeft()
	{
		return VSGRAPHXGetLeft(m_vsgraphx);
	}

	/* returns:	The top position of the drawing (in drawing's units). */
	double GetTop()
	{
		return VSGRAPHXGetTop(m_vsgraphx);
	}

	/* returns:	The right position of the drawing (in drawing's units). */
	double GetRight()
	{
		return VSGRAPHXGetRight(m_vsgraphx);
	}

	/* returns:	The bottom position of the drawing (in drawing's units). */
	double GetBottom()
	{
		return VSGRAPHXGetBottom(m_vsgraphx);
	}

	/* returns:	The width of the drawing (in drawing's units). */
	double GetWidth()
	{
		return VSGRAPHXGetWidth(m_vsgraphx);
	}
	
	/* returns:	The height of the drawing (in drawing's units). */
	double GetHeight()
	{
		return VSGRAPHXGetHeight(m_vsgraphx);
	}

	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * output:	left		-	The left position of the graphics entity (in drawing's 
	 *							units).
	 *
	 *			top			-	The top position of the graphics entity (in drawing's 
	 *							units).
	 *
	 *			right		-	The right position of the graphics entity (in drawing's 
	 *							units).
	 *
	 *			bottom		-	The bottom position of the graphics entity (in drawing's 
	 *							units).
	 *
	 * returns: TRUE for success, FALSE for failure.
	 *
	 * remarks:	Gets the boundaries of a graphics entity (in drawing's units).
	 */
	BOOL GetEntityBounds(int index, double *left, double *top, double *right, double *bottom)
	{
		return VSGRAPHXGetEntityBounds(m_vsgraphx, index, left, top, right, bottom);
	}


	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * returns:	The left position of the graphics entity (in drawing's units).
	 */
	double GetEntityLeft(int index)
	{
		return VSGRAPHXGetEntityLeft(m_vsgraphx, index);
	}


	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * returns:	The top position of the graphics entity (in drawing's units).
	 */
	double GetEntityTop(int index)
	{
		return VSGRAPHXGetEntityTop(m_vsgraphx, index);
	}


	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * returns:	The right position of the graphics entity (in drawing's units).
	 */
	double GetEntityRight(int index)
	{
		return VSGRAPHXGetEntityRight(m_vsgraphx, index);
	}


	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * returns:	The bottom position of the graphics entity (in drawing's units).
	 */
	double GetEntityBottom(int index)
	{
		return VSGRAPHXGetEntityBottom(m_vsgraphx, index);
	}


	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * returns:	The width of the graphics entity (in drawing's units).
	 */
	double GetEntityWidth(int index)
	{
		return VSGRAPHXGetEntityWidth(m_vsgraphx, index);
	}


	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * returns:	The height of the graphics entity (in drawing's units).
	 */
	double GetEntityHeight(int index)
	{
		return VSGRAPHXGetEntityHeight(m_vsgraphx, index);
	}

	/* returns:	The number of graphics entities in the drawing. */
	int GetNumOfEntities()
	{
		return VSGRAPHXGetNumOfEntities(m_vsgraphx);
	}


	/* input:	index		-	The index of the graphics entity in the drawing.
	 *			
	 * returns:	The graphics entity's type. It can be one of the following: 
	 *			VSGRAPHX_ENTITY_POLYBEZIER, VSGRAPHX_ENTITY_TEXT, VSGRAPHX_ENTITY_BITMAP.
	 *			In case of failure returns VSGRAPHX_ERROR.
	 */
	int GetEntityType(int index)
	{
		return VSGRAPHXGetEntityType(m_vsgraphx, index);
	}


	/* input:	index		-	The index of the PolyBezierPath entity in the drawing.
	 *
	 * output:	pnWidth		-	The pen width (in drawing's units) of the PolyBezierPath
	 *							entity.
	 *
	 *			pnStyle		-	The pen style of the PolyBezierPath entity.
	 *
	 *			pnColor		-	The pen color of the PolyBezierPath entity.
	 *
	 *			brStyle		-	The brush style of the PolyBezierPath entity.
	 *
	 *			brColor		-	The brush color of the PolyBezierPath entity.
	 *
	 *			hatch		-	The hatch style of the PolyBezierPath entity.
	 *
	 * returns: TRUE for success, FALSE for failure.
	 *			
	 * remarks:	Gets the info about the pen and brush that are used for drawing a
	 *			PolyBezierPath entity.
	 */
	BOOL GetPolyBezierPathInfo(int index, double *pnWidth, UINT *pnStyle, 
						COLORREF *pnColor, UINT *brStyle, COLORREF *brColor, LONG *hatch)
	{
		return VSGRAPHXGetPolyBezierPathInfo(m_vsgraphx, index, pnWidth, pnStyle, pnColor,
											 brStyle, brColor, hatch);
	}


	/* input:	index		-	The index of the PolyBezierPath entity in the drawing.
	 *			
	 * returns:	The number of Bezier paths that a PolyBezierPath entity has.
	 */
	int GetPolyBezierPathSize(int index)
	{
		return VSGRAPHXGetPolyBezierPathSize(m_vsgraphx, index);
	}


	/* input:	index		-	The index of the PolyBezierPath entity in the drawing.
	 *
	 *			path		-	The index of the Bezier path in the PolyBezierPath entity.
	 *			
	 * returns:	The number of triplets that a Bezier path has.
	 */
	int GetBezierPathSize(int index, int path)
	{
		return VSGRAPHXGetBezierPathSize(m_vsgraphx, index, path);
	}


	/* input:	index		-	The index of the PolyBezierPath entity in the drawing.
	 *
	 *			path		-	The index of the Bezier path in the PolyBezierPath entity.
	 *
	 *			trIndex		-	The index of the triplet in the Bezier path.
	 *
	 * output:	preDirPoX	-	The x coordinate (in drawing's units) of the Bezier
	 *							triplet's pre-direction point.
	 *
	 *			preDirPoY	-	The y coordinate (in drawing's units) of the Bezier
	 *							triplet's pre-direction point.
	 *
	 *			anchPoX		-	The x coordinate (in drawing's units) of the Bezier
	 *							triplet's anchor point.
	 *
	 *			anchPoY		-	The y coordinate (in drawing's units) of the Bezier
	 *							triplet's anchor point.
	 *
	 *			postDirPoX	-	The x coordinate (in drawing's units) of the Bezier
	 *							triplet's post-direction point.
	 *
	 *			postDirPoY	-	The y coordinate (in drawing's units) of the Bezier
	 *							triplet's post-direction point.
	 *
	 * returns: TRUE for success, FALSE for failure.
	 *			
	 * remarks:	Gets the coordinates (in drawing's units) of a Bezier path triplet.
	 */
	BOOL GetBezierPathTriplet(int index, int path, int trIndex,
							  double *preDirPoX, double *preDirPoY, 
							  double *anchPoX,  double *anchPoY, 
							  double *postDirPoX, double *postDirPoY)
	{
		return VSGRAPHXGetBezierPathTriplet(m_vsgraphx, index, path, trIndex,
						preDirPoX, preDirPoY, anchPoX, anchPoY, postDirPoX, postDirPoY);
	}


	/* input:	index		-	The index of the Text entity in the drawing.
	 *
	 * output:	poX			-	The x coordinate (in drawing's units) of the Text
	 *							entity's top left point.
	 *
	 *			poY			-	The y coordinate (in drawing's units) of the Text
	 *							entity's top left point.
	 *
	 *			style		-	The style of the Text entity. The text style can be a
	 *							combination of the following: VSGRAPHX_TEXT_STYLE_NORMAL,
	 *							VSGRAPHX_TEXT_STYLE_ITALIC, VSGRAPHX_TEXT_STYLE_BOLD, 
	 *							VSGRAPHX_TEXT_STYLE_UNDERLINE.
	 *
	 *			height		-	The height (in drawing's units) of the Text entity.
	 *
	 *			angle		-	The angle (in degrees) of the Text entity.
	 *
	 *			color		-	The color of the Text entity.
	 *
	 * returns: TRUE for success, FALSE for failure.
	 *			
	 * remarks:	Gets the coordinates (in drawing's units) of a Text entity's top
	 *			left point, as well as the style, height (in drawing's units), 
	 *			angle (in degrees) and color of the Text entity.
	 */
	BOOL GetTextInfo(int index, double *poX, double *poY, BYTE *style, double *height, 
					 double *angle, COLORREF *color)
	{
		return VSGRAPHXGetTextInfo(m_vsgraphx, index, poX, poY, style, height, 
								   angle, color);
	}


	/* input:	index		-	The index of the Text entity in the drawing.
	 *
	 *			nSize		-	Specifies the length of the lpFontName buffer. If the
	 *							length of the font name exceeds this limit, the string
	 *							is truncated.
	 *
	 * output:	lpFontName	-	A buffer that receives the font name string.
	 *
	 * returns:	The length of the string copied to the buffer. If the lpFontname
	 *			argument is NULL, it returns the actual length of the font name
	 *			string. In case of failure returns VSGRAPHX_ERROR.
	 */
	int GetFontName(int index, LPTSTR lpFontName, DWORD nSize)
	{
		return VSGRAPHXGetFontName(m_vsgraphx, index, lpFontName, nSize);
	}


	/* input:	index		-	The index of the Text entity in the drawing.
	 *
	 *			size		-	Specifies the length of the lpText buffer. If the length
	 *							of the text exceeds this limit, the string is truncated.
	 *
	 * output:	lpText		-	A buffer that receives the text string.
	 *
	 * returns:	The length of the string copied to the buffer. If the lpText argument
	 *			is NULL it returns the actual length of the Text entity's string. In
	 *			case of failure returns VSGRAPHX_ERROR.
	 */
	int GetText(int index, LPTSTR lpText, DWORD nSize)
	{
		return VSGRAPHXGetText(m_vsgraphx, index, lpText, nSize);
	}


	/* input:	index		-	The index of the Bitmap entity in the drawing.
	 *			
	 * returns:	The HBITMAP of the Bitmap entity, or NULL in case of failure.
	 *
	 * remarks: Do not destroy the returned HBITMAP. It will be destroyed by Close().
	 */
	HBITMAP GetBitmap(int index)
	{
		return VSGRAPHXGetBitmap(m_vsgraphx, index);
	}


	/* input:	pnWidth		-	The pen width (in drawing's units) of the 
	 *							PolyBezierPath entity.
	 *
	 *			pnStyle		-	The pen style of the PolyBezierPath entity.
	 *
	 *			pnColor		-	The pen color of the PolyBezierPath entity.
	 *
	 *			brStyle		-	The brush style of the PolyBezierPath entity.
	 *
	 *			brColor		-	The brush color of the PolyBezierPath entity.
	 *
	 *			hatch		-	The hatch style of the PolyBezierPath entity.
	 *			
	 * returns:	TRUE for success, FALSE for failure.
	 *
	 * remarks:	Begins the creation of a PolyBezierPath entity and sets the info about
	 *			the pen and brush that are used for drawing this entity. The entity must be
	 *			filled with Bezier path triplets using the AddBezierPathTriplet() method.
	 *			Multiple Bezier paths can be added to the PolyBezierPath entity using the
	 *			AddBezierPath() method.
	 */
	BOOL BeginPolyBezierPath(double pnWidth, UINT pnStyle, COLORREF pnColor, UINT brStyle, 
							 COLORREF brColor, LONG hatch)
	{
		return VSGRAPHXBeginPolyBezierPath(m_vsgraphx, pnWidth, pnStyle, pnColor, 
										   brStyle, brColor, hatch);
	}


	/* input:	preDirPoX	-	The x coordinate (in drawing's units) of the triplet's
	 *							pre-direction point.
	 *
	 *			preDirPoY	-	The y coordinate (in drawing's units) of the triplet's
	 *							pre-direction point.
	 *
	 *			anchPoX		-	The x coordinate (in drawing's units) of the triplet's
	 *							anchor point.
	 *
	 *			anchPoY		-	The y coordinate (in drawing's units) of the triplet's
	 *							anchor point.
	 *
	 *			postDirPoX	-	The x coordinate (in drawing's units) of the triplet's
	 *							post-direction point.
	 *
	 *			postDirPoY	-	The y coordinate (in drawing's units) of the triplet's
	 *							post-direction point.
	 *			
	 * returns:	TRUE if BeginPolyBezierPath() has been called. FALSE otherwise.
	 *
	 * remarks:	Adds a Bezier path triplet to the current Bezier path of the
	 *			PolyBezierPath entity under creation.
	 */
	BOOL AddBezierPathTriplet(double preDirPoX, double preDirPoY, 
							  double anchPoX,  double anchPoY, 
							  double postDirPoX, double postDirPoY)
	{
		return VSGRAPHXAddBezierPathTriplet(m_vsgraphx, preDirPoX, preDirPoY, 
									 anchPoX,  anchPoY, postDirPoX, postDirPoY);
	}


	/* returns:	TRUE if BeginPolyBezierPath() has been called and the current Bezier
	 *			path of the PolyBezierPath entity is not empty. FALSE otherwise.
	 *
	 * remarks:	Adds another Bezier path to the PolyBezierPath entity under creation
	 *			It is needed only for PolyBezierPath entities that contain more than
	 *			one Bezier paths.
	 */
	BOOL AddBezierPath()
	{
		return VSGRAPHXAddBezierPath(m_vsgraphx);
	}


	/* returns:	TRUE if a PolyBezierPath entity has been created using the methods 
	 *			BeginPolyBezierPath() and AddBezierPathTriplet(). FALSE otherwise.
	 *
	 * remarks:	Adds a PolyBezierPath entity to the end of a drawing. The entity
	 *			must have been created using the BeginPolyBezierPath() and
	 *			AddBezierPathTriplet() methods. For PolyBezierPath entities that have
	 *			more than one Bezier paths, AddBezierPath() must also have been used.
	 */
	BOOL AddPolyBezierPath()
	{
		return VSGRAPHXAddPolyBezierPath(m_vsgraphx);
	}


	/* input:	text		-	The text string of the Text entity.
	 *
	 *			fontName	-	The font name string of the Text entity.
	 *
	 *			poX			-	The x coordinate (in drawing's units) of the Text
	 *							entity's top left point.
	 *
	 *			poY			-	The y coordinate (in drawing's units) of the Text
	 *							entity's top left point.
	 *
	 *			style		-	The style of the Text entity. The text style can be a
	 *							combination of the following: VSGRAPHX_TEXT_STYLE_NORMAL,
	 *							VSGRAPHX_TEXT_STYLE_ITALIC, VSGRAPHX_TEXT_STYLE_BOLD, 
	 *							VSGRAPHX_TEXT_STYLE_UNDERLINE.
	 *
	 *			height		-	The height (in drawing's units) of the Text entity.
	 *
	 *			angle		-	The angle (in degrees) of the Text entity.
	 *
	 *			color		-	The color of the Text entity.
	 *			
	 * returns:	TRUE for success, FALSE for failure.
	 *
	 * remarks:	Adds a Text entity to the end of a drawing.
	 */
	BOOL AddText(LPCTSTR text, LPCTSTR fontName, double poX, double poY,
				 BYTE style, double height, double angle, COLORREF color)
	{
		return VSGRAPHXAddText(m_vsgraphx, text, fontName, poX, poY,
							   style, height, angle, color);
	}


	/* input:	hBmp		-	The HBITMAP of the Bitmap entity. This HBITMAP will be
	 *							deleted by VSGRAPHXClose().
	 *
	 *			left		-	The left position (in drawing's units) of the Bitmap
	 *							entity.
	 *
	 *			top			-	The top position (in drawing's units) of the Bitmap
	 *							entity.
	 *
	 *			right		-	The right position (in drawing's units) of the Bitmap
	 *							entity.
	 *
	 *			bottom		-	The bottom position (in drawing's units) of the Bitmap
	 *							entity.
	 *			
	 * returns:	TRUE for success, FALSE for failure.
	 *
	 * remarks:	Adds a Bitmap entity to the end of a drawing.
	 */
	BOOL AddBitmap(HBITMAP hBmp, double left, double top, double right, double bottom)
	{
		return VSGRAPHXAddBitmap(m_vsgraphx, hBmp, left, top, right, bottom);
	}


	/* returns:	The units that are used in the drawing. Possible values are 
	 *			VSGRAPHX_UNITS_PX, VSGRAPHX_UNITS_MM10, VSGRAPHX_UNITS_MM, 
	 *			VSGRAPHX_UNITS_CM, VSGRAPHX_UNITS_IN and VSGRAPHX_ERROR in case of 
	 *			failure. The default units in a drawing are tenths of millimeters
	 *			(VSGRAPHX_UNITS_MM10).
	 */
	int GetUnits()
	{
		return VSGRAPHXGetUnits(m_vsgraphx);
	}


	/* input:	units		-	The units to be used in the drawing. Possible values are
	 *							VSGRAPHX_UNITS_PX, VSGRAPHX_UNITS_MM10, VSGRAPHX_UNITS_MM, 
	 *							VSGRAPHX_UNITS_CM, VSGRAPHX_UNITS_IN.
	 *			
	 * remarks:	Sets the units to be used in a drawing. The default units in a drawing
	 *			are tenths of millimeters (VSGRAPHX_UNITS_MM10).
	 */
	void SetUnits(int units)
	{
		VSGRAPHXSetUnits(m_vsgraphx, units);
	}


	/* input:	width		-	The width of the icon.
	 *
	 *			height		-	The height of the icon.
	 *
	 *			first		-	The index of the first entity to be drawn to the icon.
	 *
	 *			last		-	The index of the last entity to be drawn to the icon.
	 *
	 * returns: The HBITMAP of the icon, or NULL in case of failure.
	 *			
	 * remarks: Creates an icon containing some graphics entities  of a drawing. The
	 *			returned HBITMAP must be deleted when it is no longer needed.
	 */
	HBITMAP CreateIcon(int width, int height, int first, int last)
	{
		return VSGRAPHXCreateIcon(m_vsgraphx, width, height, first, last);
	}


	/* input:	hBmp		-	The HBITMAP to be copied.
	 *			
	 * returns:	A new 24-bit device independent HBITMAP with the image of the argument
	 *			HBITMAP. The returned HBITMAP must be deleted when it is no longer needed.
	 */
	static HBITMAP CreateBitmap24(HBITMAP hBmp)
	{
		return VSGRAPHXCreateBitmap24(hBmp);
	}

protected:
		/* The vsgraphx handle to the last opened file. */
		/* FOR INTERNAL USE ONLY */
	int m_vsgraphx;

};
#endif

#endif /* !defined(_VSGRAPHXAPI_INCLUDED) */


