// CustomFileDlg.cpp : implementation file
//

#include "stdafx.h"
#include "CustomFileDlg.h"
#include <desapi.h>

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif


//checks if a file exists
static BOOL ExistsFile(const char* name)
{
	DWORD atr = GetFileAttributes(name);
	if(atr == 0xFFFFFFFF)
		return FALSE;
	return TRUE;
}


//changes the extension of a filepath string
static void ChangeExtension(CString &cs, CString ext)
{
	int dot_index=cs.ReverseFind('.');
	if (dot_index!=-1)
		cs=cs.Left(dot_index);
	if (ext.GetLength())
		cs+="."+ext;
}



/////////////////////////////////////////////////////////////////////////////
// CCustomFileDlg

IMPLEMENT_DYNAMIC(CCustomFileDlg, CFileDialog)

CCustomFileDlg::CCustomFileDlg(BOOL bOpenFileDialog, const char *filename, 
							   const char *filter, CWnd* pParentWnd) :
		CFileDialog(
			bOpenFileDialog, 
			NULL, 
			filename, 
			OFN_HIDEREADONLY, 
			filter, pParentWnd)
{
	m_bOpenFileDialog = bOpenFileDialog;

	if (!bOpenFileDialog)
	{
		m_extar.Add("Adobe Illustrator v7 (AI)|*.ai|");
		m_extar.Add("AutoCAD 2002 (DXF)|*.dxf|");
		m_extar.Add("Enhanced Metafile (EMF)|*.emf|");
		m_extar.Add("HPGL Plotter file (PLT)|*.plt|");
	}
}

BEGIN_MESSAGE_MAP(CCustomFileDlg, CFileDialog)
	//{{AFX_MSG_MAP(CCustomFileDlg)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

BOOL CCustomFileDlg::OnFileNameOK()
{
	if (!m_bOpenFileDialog)
	{
		CString name=GetPathName();

		if (ExistsFile(name))
		{
			CString msg;
			msg.Format(_T("%s already exists.\nDo you want to replace it?"), name);
			CString caption = _T("VSGraphX Sample");
			if (::MessageBox(NULL, msg, caption, MB_YESNO) == IDNO)
				return TRUE;
		}
	}

	return CFileDialog::OnFileNameOK();
}


//returns the dialog's current selected extension
CString CCustomFileDlg::GetSelectedExt()
{
	int findex;
	int count=0;
	CString ext;

	findex=m_ofn.nFilterIndex-1;
	if (findex<0 || findex>=m_extar.GetSize())
		return ext;

	int sindex=m_extar[findex].Find("*.");
	if (sindex==-1)
		return ext;
	ext=m_extar[findex].Right(m_extar[findex].GetLength()-sindex-2);
	ext=ext.Left(ext.GetLength()-1);
	return ext;
}	

//returns the dialog's current filepath
CString CCustomFileDlg::GetPathName()
{
	CString name=CFileDialog::GetPathName();
	if (m_bOpenFileDialog)
		return name;

	CString ext=GetFileExt();
	if (!ext.GetLength())
	{
		ext=GetSelectedExt();
		ChangeExtension(name,ext);
	}
	return name;
}

