// VSGraphXSampleDoc.cpp : implementation of the CVSGraphXSampleDoc class
//

#include "stdafx.h"
#include "VSGraphXSample.h"

#include "VSGraphXSampleDoc.h"
#include "VSGraphXSampleView.h"
#include "CustomFileDlg.h"
#include "MainFrm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CVSGraphXSampleDoc

IMPLEMENT_DYNCREATE(CVSGraphXSampleDoc, CDocument)

BEGIN_MESSAGE_MAP(CVSGraphXSampleDoc, CDocument)
	//{{AFX_MSG_MAP(CVSGraphXSampleDoc)
	ON_COMMAND(ID_FILE_SAVE_AS, OnFileSaveAs)
		// NOTE - the ClassWizard will add and remove mapping macros here.
		//    DO NOT EDIT what you see in these blocks of generated code!
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CVSGraphXSampleDoc construction/destruction

CVSGraphXSampleDoc::CVSGraphXSampleDoc()
{
	m_graphx = NULL;
}

CVSGraphXSampleDoc::~CVSGraphXSampleDoc()
{
	delete m_graphx;
}


BOOL CVSGraphXSampleDoc::OnNewDocument()
{
	if (!CDocument::OnNewDocument())
		return FALSE;

	delete m_graphx;
	m_graphx = NULL;

	((CMainFrame *) AfxGetMainWnd())->m_entitiesBar.UpdateList(m_graphx);

	CVSGraphXSampleView *cv = GetView();
	if (cv)
		cv->SetSelection(-1);

	SetTitle(_T("Untitled"));

	return TRUE;
}


BOOL CVSGraphXSampleDoc::OnOpenDocument(LPCTSTR lpszPathName) 
{
	if (!CDocument::OnOpenDocument(lpszPathName))
		return FALSE;

	CVSGraphXSampleView *cv = GetView();
	if (!cv)
		return FALSE;

	CVSGraphX *graphx = new CVSGraphX;
	
	//Open the document
	if (graphx->Open(lpszPathName))
	{
		delete m_graphx;
		m_graphx = graphx;
	}
	else
	{
		delete graphx;
		return false;
	}

	m_graphx->SetUnits(cv->GetUnits());

	//Fit to window
	cv->PostMessage(WM_COMMAND, ID_ZOOM_FIT);
	cv->SetSelection(-1);

	//Update the entities bar
	((CMainFrame *) AfxGetMainWnd())->m_entitiesBar.UpdateList(m_graphx);

	return TRUE;
}


void CVSGraphXSampleDoc::OnFileSaveAs() 
{
	CVSGraphXSampleView *cv = GetView();
	if (!cv)
		return;
	
	static LPCTSTR szFilter = _T("Adobe Illustrator v7 (AI)|*.ai|AutoCAD 2002 (DXF)|*.dxf|Enhanced Metafile (EMF)|*.emf|HPGL Plotter file (PLT)|*.plt||");

	CCustomFileDlg dlg(FALSE,NULL,szFilter);
	if (dlg.DoModal()==IDOK)
	{
		//Save the drawing and open the saved file
		if (Save(dlg.GetPathName()))
			AfxGetApp()->OpenDocumentFile(dlg.GetPathName());
	}
}


//Saves a drawing to a file specified by the lpszPathName argument
BOOL CVSGraphXSampleDoc::Save(LPCTSTR lpszPathName)
{
	if (!m_graphx)
		return FALSE;

	//We could have saved the m_graphx drawing at once with this line code:
	//return m_graphx.Save(lpszPathName);

	//However, what we do here is to traverse the drawing's entities, add them
	//to a new drawing and save the new drawing. This is done as an example of 
	//traversing the entities of a drawing and adding entities to a drawing.	

	CVSGraphX graphx;
	graphx.Create();
	graphx.SetUnits(m_graphx->GetUnits());

	int size = m_graphx->GetNumOfEntities();
	for (int i=0;i<size;i++)
	{
		int type = m_graphx->GetEntityType(i);
		if (type == VSGRAPHX_ENTITY_POLYBEZIER)
		{
			double pnWidth;
			UINT pnStyle, brStyle;
			COLORREF pnColor, brColor;
			LONG hatch;

			BOOL result = m_graphx->GetPolyBezierPathInfo(i, &pnWidth, &pnStyle, 
												&pnColor, &brStyle, &brColor, &hatch);
			if (!result)
				continue;

			graphx.BeginPolyBezierPath(pnWidth, pnStyle, pnColor, 
									   brStyle, brColor, hatch);

			int polyBezierPathSize = m_graphx->GetPolyBezierPathSize(i);
			for (int j=0;j<polyBezierPathSize;j++)
			{
				int bezierPathSize = m_graphx->GetBezierPathSize(i, j);
				if (bezierPathSize == 0)
					continue;

				graphx.AddBezierPath();

				for (int k=0;k<bezierPathSize;k++)
				{
					double preDirPoX, preDirPoY, anchPoX, anchPoY,
						   postDirPoX, postDirPoY;

					result = m_graphx->GetBezierPathTriplet(i, j, k,
															&preDirPoX, &preDirPoY, 
															&anchPoX,  &anchPoY, 
															&postDirPoX, &postDirPoY);

					if (!result)
						continue;

					graphx.AddBezierPathTriplet(preDirPoX, preDirPoY, 
												anchPoX,  anchPoY, 
												postDirPoX, postDirPoY);
				}
			}

			graphx.AddPolyBezierPath();
		}
		else if (type == VSGRAPHX_ENTITY_TEXT)
		{
			double poX, poY, height, angle;
			BYTE style;
			COLORREF color;
			BOOL result = m_graphx->GetTextInfo(i, &poX, &poY, &style, 
													&height, &angle, &color);
			if (!result)
				continue;

			int length = m_graphx->GetText(i, NULL, 0);
			if (length == VSGRAPHX_ERROR)
				continue;
			LPTSTR lpText = new TCHAR[length+1];
			lpText[length] = _T('\0');

			result = m_graphx->GetText(i, lpText, length);
			if (result == VSGRAPHX_ERROR)
			{
				delete lpText;
				continue;
			}

			length = m_graphx->GetFontName(i, NULL, 0);
			if (length == VSGRAPHX_ERROR)
			{
				delete lpText;
				continue;
			}

			LPTSTR lpFontName = new TCHAR[length+1];
			lpFontName[length] = _T('\0');

			result = m_graphx->GetFontName(i, lpFontName, length);
			if (result == VSGRAPHX_ERROR)
			{
				delete lpText;
				delete lpFontName;
				continue;
			}

			graphx.AddText(lpText, lpFontName, poX, poY, style, height, angle, color);
			delete lpText;
			delete lpFontName;
		}
		else if (type == VSGRAPHX_ENTITY_BITMAP)
		{
			double left, top, right, bottom;
			BOOL result = m_graphx->GetEntityBounds(i, &left, &top, &right, &bottom);
			if (result == VSGRAPHX_ERROR)
				continue;

			HBITMAP hBmp = m_graphx->GetBitmap(i);
			if (!hBmp)
				continue;

			HBITMAP hBmp2 = m_graphx->CreateBitmap24(hBmp);
			if (!hBmp2)
				continue;

			graphx.AddBitmap(hBmp2, left, top, right, bottom);
		}
	}

	//Save the drawing.
	return graphx.Save(lpszPathName);
}

//Sets the title of the document.
void CVSGraphXSampleDoc::SetTitle(LPCTSTR lpszTitle)
{
	CVSGraphXSampleView *cv = GetView();
	if (!cv)
		return;

	CString title = lpszTitle;
	if (m_graphx && m_graphx->GetNumOfEntities() > 0)
	{
		double width = m_graphx->GetWidth();
		double height = m_graphx->GetHeight();
		CString unitsStr = cv->GetUnitsString();
		CString str;
		str.Format(_T(" (Width: %.2f %s, Height: %.2f %s)"), width, unitsStr, height, unitsStr);
		title += str;
	}

	CDocument::SetTitle(title);
}


//Returns a pointer to the View
CVSGraphXSampleView * CVSGraphXSampleDoc::GetView()
{
	CView *acv=((CFrameWnd*)AfxGetMainWnd())->GetActiveView();
	if (!acv)
		return NULL;

	CVSGraphXSampleView *cv=(CVSGraphXSampleView *)acv;
	if (!cv->IsKindOf(RUNTIME_CLASS(CVSGraphXSampleView)))
		return NULL;
	return cv;
}


/////////////////////////////////////////////////////////////////////////////
// CVSGraphXSampleDoc serialization

void CVSGraphXSampleDoc::Serialize(CArchive& ar)
{
	if (ar.IsStoring())
	{
		// TODO: add storing code here
	}
	else
	{
		// TODO: add loading code here
	}
}

/////////////////////////////////////////////////////////////////////////////
// CVSGraphXSampleDoc diagnostics

#ifdef _DEBUG
void CVSGraphXSampleDoc::AssertValid() const
{
	CDocument::AssertValid();
}

void CVSGraphXSampleDoc::Dump(CDumpContext& dc) const
{
	CDocument::Dump(dc);
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CVSGraphXSampleDoc commands

